AppHelpCenterLocalizations class

Constructors

AppHelpCenterLocalizations({required Locale locale, Map<String, String> overrides = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
locale Locale
final
overrides Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(String key, Object value) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text(String key) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context, {Locale? locale, Map<String, String> overrides = const {}}) AppHelpCenterLocalizations