VersionHistoryItem class
Constructors
-
VersionHistoryItem({String? id, required String versionName, required DateTime publishedAt, required String changes, String? videoTitle, List<
HelpVideoLink> videoLinks = const []}) -
VersionHistoryItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- changes → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasVideoLinks → bool
-
no setter
- id → String
-
final
- publishedAt → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionName → String
-
final
-
videoLinks
→ List<
HelpVideoLink> -
final
- videoTitle → String?
-
final
Methods
-
copyWith(
{String? id, String? versionName, DateTime? publishedAt, String? changes, String? videoTitle, List< HelpVideoLink> ? videoLinks}) → VersionHistoryItem -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited